/*
Copyright (c) 2003 Maksim Orlovich <maksim.orlovich@kdemail.net>

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.

*/

#include <stdlib.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qsettings.h>

#include <qvbuttongroup.h>
#include <qvgroupbox.h>
#include <qhbox.h>
#include <qradiobutton.h>
#include <qtabwidget.h>
#include <qslider.h>
#include <qlabel.h>
#include <qdir.h>
#include <qfile.h>
#include <qmessagebox.h>

#include <kdialog.h>
#include <kglobal.h>
#include <klocale.h>
#include <kfiledialog.h>
#include <kconfig.h>
#include <kapplication.h>
#include <dcopclient.h>

#include "thinkeramikconf.h"

bool disableKMenuTitlesOld = false;

extern "C"
{
    QWidget* allocate_kstyle_config(QWidget* parent)
    {
        return new ThinKeramikStyleConfig(parent);
    }
}

ThinKeramikStyleConfig::ThinKeramikStyleConfig(QWidget* parent): QWidget(parent)
{
    //Should have no margins here, the dialog provides them
    QVBoxLayout *layout = new QVBoxLayout(this, 0, 0);
    KGlobal::locale()->insertCatalogue("kstyle_thinkeramik_config");

    QTabWidget *tabWidget = new QTabWidget(this);
    layout->addWidget(tabWidget);

    //--- tab 1 ---

    QWidget *page1 = new QWidget(tabWidget);
    tabWidget->insertTab(page1, i18n("Menu Options 1"));

    layout = new QVBoxLayout(page1);
    layout->addSpacing(5);

    // Menu colors
    QVGroupBox *colorGrp1 = new QVGroupBox(i18n("Menu colors"), page1);
    QWidget *colorFrame1  = new QWidget(colorGrp1);
    QGridLayout *cLayout1 = new QGridLayout(colorFrame1, 1, 1, 2);

    useCustomColorBtn1 = new QCheckBox(i18n("Use custom colors"), colorFrame1);
    cLayout1->addMultiCellWidget(useCustomColorBtn1, 1, 1, 0, 3);

    cLayout1->addWidget(new QLabel(i18n("Widget:"), colorFrame1), 2, 0);
    cLayout1->addWidget(new QLabel(i18n("Color:"), colorFrame1), 2, 1);

    cLayout1->addWidget(new QLabel(i18n("Foreground:"), colorFrame1), 3, 0);
    cLayout1->addWidget(new QLabel(i18n("Background:"), colorFrame1), 4, 0);
    cLayout1->addWidget(new QLabel(i18n("Stripe:"), colorFrame1), 5, 0);
    cLayout1->addWidget(new QLabel(i18n("Separator:"), colorFrame1), 6, 0);

    menuFgBtn = new KColorButton(colorFrame1);
    cLayout1->addWidget(menuFgBtn, 3, 1);
    menuBgBtn = new KColorButton(colorFrame1);
    cLayout1->addWidget(menuBgBtn, 4, 1);
    menuStripeBtn = new KColorButton(colorFrame1);
    cLayout1->addWidget(menuStripeBtn, 5, 1);
    menuSeparatorBtn = new KColorButton(colorFrame1);
    cLayout1->addWidget(menuSeparatorBtn, 6, 1);
 
    cLayout1->addMultiCellWidget(new QLabel(i18n("Custom menu colors are effective in"), colorFrame1), 7, 7, 0, 3);
    cLayout1->addMultiCellWidget(new QLabel(i18n("XRender-Blend mode or Disable-Translucent mode."), colorFrame1), 8, 8, 1, 3);

    enableGradBtn = new QCheckBox(i18n("Enable gradation in the XRender-Blend mode"), colorFrame1);
    cLayout1->addMultiCellWidget(enableGradBtn, 9, 9, 0, 3);

    customGradBtn = new QCheckBox(i18n("Custom gradation (Background color to Stripe color)"), colorFrame1);
    cLayout1->addMultiCellWidget(customGradBtn, 10, 10, 1, 3);

    connect(useCustomColorBtn1, SIGNAL(toggled(bool)), this,
            SLOT(slotUseCustomColor1Clicked(bool)));
    connect(menuFgBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(menuBgBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(menuStripeBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(menuSeparatorBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(enableGradBtn, SIGNAL(toggled(bool)), this,
            SLOT(slotEnableGradClicked(bool)));
    connect(customGradBtn, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));

    cLayout1->setColStretch(3, 1);
    layout->addWidget(colorGrp1);
    layout->addSpacing(5);

    // Menu Border
    QVGroupBox *colorGrp1b = new QVGroupBox(i18n("Menu Border"), page1);
    useCustomColorBtn1b = new QCheckBox(i18n("Draw menu border"), colorGrp1b);
    connect(useCustomColorBtn1b, SIGNAL(toggled(bool)), this,
            SLOT(slotUseCustomColor1bClicked(bool)));
    QHBox *colorBox1b = new QHBox(colorGrp1b);
    QLabel *borderColBtnLbl = new QLabel(i18n("Border color:"), colorBox1b);
    borderColBtn = new KColorButton(colorBox1b);
    connect(borderColBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    colorBox1b->setStretchFactor(new QWidget(colorBox1b), 1);
    layout->addWidget(colorGrp1b);

    layout->addSpacing(5);

    // Selected Menu Item colors
    QVGroupBox *colorGrp1c = new QVGroupBox(i18n("Selected Menu Item"), page1);
    QWidget *colorFrame1c  = new QWidget(colorGrp1c);
    QGridLayout *cLayout1c = new QGridLayout(colorFrame1c, 1, 1, 2);

    useCustomColorBtn1c = new QCheckBox(i18n("Use custom colors"), colorFrame1c);
    cLayout1c->addMultiCellWidget(useCustomColorBtn1c, 1, 1, 0, 2);

    cLayout1c->addWidget(new QLabel(i18n("Widget:"), colorFrame1c), 2, 0);
    cLayout1c->addWidget(new QLabel(i18n("Color:"), colorFrame1c), 2, 1);

    cLayout1c->addWidget(new QLabel(i18n("Foreground:"), colorFrame1c), 3, 0);
    cLayout1c->addWidget(new QLabel(i18n("Background:"), colorFrame1c), 4, 0);
    cLayout1c->addWidget(new QLabel(i18n("Shadow:"), colorFrame1c), 5, 0);

    menuSelFgBtn = new KColorButton(colorFrame1c);
    cLayout1c->addWidget(menuSelFgBtn, 3, 1);
    menuSelBgBtn = new KColorButton(colorFrame1c);
    cLayout1c->addWidget(menuSelBgBtn, 4, 1);
    menuSelShdBtn = new KColorButton(colorFrame1c);
    cLayout1c->addWidget(menuSelShdBtn, 5, 1);

    connect(useCustomColorBtn1c, SIGNAL(toggled(bool)), this,
            SLOT(slotUseCustomColor1cClicked(bool)));
    connect(menuSelFgBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(menuSelBgBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(menuSelShdBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));


    cLayout1c->setColStretch(2, 1);
    layout->addWidget(colorGrp1c);

    layout->addStretch(1);

    //--- tab 1-2 ---

    QWidget *page1p2 = new QWidget(tabWidget);
    layout = new QVBoxLayout(page1p2);
    layout->addSpacing(5);
    tabWidget->insertTab(page1p2, i18n("Menu Options 2"));

    // Menu BG Image
    QVGroupBox *bgiGrp = new QVGroupBox(i18n("Menu Background Image"), page1p2);
    useMenuBGI = new QCheckBox(i18n("Draw menu background image (XRender-Blend mode only)"), bgiGrp);
    connect(useMenuBGI, SIGNAL(toggled(bool)), this,
            SLOT(slotUseMenuBGIClicked(bool)));

    QHBox *bgiBox = new QHBox(bgiGrp);
    QLabel *menubgfileLbl = new QLabel(i18n("Image File:"), bgiBox);
    menubgfile = new QLineEdit(bgiBox);
    menubgfile->setMinimumSize(300,8);
    menubgBrowse = new QPushButton(i18n("Browse..."),bgiBox);

    QHBox *bgiBox2 = new QHBox(bgiGrp);
    QLabel *menubgfileLbldmy1 = new QLabel(i18n("     "), bgiBox2);
    scaledMenuBGI = new QCheckBox(i18n("Use scaled image (Default is tiled)"), bgiBox2);

    connect(menubgfile, SIGNAL(textChanged(const QString &)), this,
            SLOT(slotTextChanged(const QString &)));
    connect(menubgBrowse, SIGNAL(clicked()), this,
            SLOT(slotMenuBGIBrowser()));
    connect(scaledMenuBGI, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));

    QLabel *useMenuBGILbl1 = new QLabel(i18n("If a menu background image is used, neither custom settings of"), bgiGrp);
    QLabel *useMenuBGILbl2 = new QLabel(i18n("the menu background and the menu stripe nor use of gradation are effective."), bgiGrp);

    bgiBox->setStretchFactor(new QWidget(bgiBox), 1);
    bgiBox2->setStretchFactor(new QWidget(bgiBox2), 1);
    layout->addWidget(bgiGrp);
    layout->addSpacing(5);

    // Menu 3D Effect
    QVGroupBox *effectGrp3d = new QVGroupBox(i18n("3D Effect of Menu"), page1p2);

    QLabel *enableMenu3dLbl = new QLabel(i18n("Check widgets which enable 3D effect."), effectGrp3d);
    QLabel *enableMenu3dLbldmy1 = new QLabel("", effectGrp3d);
    enableMI3d = new QCheckBox(i18n("Selected menu item"), effectGrp3d);
    strong3dmi = new QCheckBox(i18n("Strong 3D effect for selected menu item"), effectGrp3d);
    QLabel *enableMenu3dLbldmy2 = new QLabel("", effectGrp3d);
    enableMS3d = new QCheckBox(i18n("Menu stripe"), effectGrp3d);
    strong3dms = new QCheckBox(i18n("Strong 3D effect for menu stripe"), effectGrp3d);
    QLabel *enableMenu3dLbldmy3 = new QLabel("", effectGrp3d);
    QLabel *enableMenu3dLbl2 = new QLabel(i18n("In custom gradation mode or using menu background image,"), effectGrp3d);
    QLabel *enableMenu3dLbl3 = new QLabel(i18n("menu stripe 3D effect is invalid."), effectGrp3d);

    connect(enableMI3d, SIGNAL(toggled(bool)), this,
            SLOT(slotEnable3DMIBtnClicked(bool)));
    connect(strong3dmi, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(enableMS3d, SIGNAL(toggled(bool)), this,
            SLOT(slotEnable3DMSBtnClicked(bool)));
    connect(strong3dms, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));

    layout->addWidget(effectGrp3d);

    layout->addStretch(1);

    //--- tab 2 ---

    QWidget *page2 = new QWidget(tabWidget);
    layout = new QVBoxLayout(page2);
    layout->addSpacing(5);

    tabWidget->insertTab(page2, i18n("Custom Colors"));

    // Upper lines of Active Tab
    QVGroupBox *colorGrp2 = new QVGroupBox(i18n("Upper lines of Active Tab"), page2);
    QHBox *colorBox2 = new QHBox(colorGrp2);
    useCustomColorBtn2 = new QCheckBox(i18n("Use custom color"), colorBox2);
    connect(useCustomColorBtn2, SIGNAL(toggled(bool)), this,
            SLOT(slotUseCustomColor2Clicked(bool)));
    activeTabBtn = new KColorButton(colorBox2);
    connect(activeTabBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));

    QLabel *uplOrLbl = new QLabel(i18n("   or   "), colorBox2);
    disableUpperLinesBtn = new QCheckBox(i18n("Disable upper lines"), colorBox2);
    connect(disableUpperLinesBtn, SIGNAL(toggled(bool)), this,
            SLOT(slotDisableUpperLinesClicked(bool)));

    colorBox2->setStretchFactor(new QWidget(colorBox2), 1);
    layout->addWidget(colorGrp2);
    layout->addSpacing(5);

    // Scrollbar colors
    QVGroupBox *colorGrp3 = new QVGroupBox(i18n("Scrollbar colors"), page2);
    QWidget *colorFrame3  = new QWidget(colorGrp3);
    QGridLayout *cLayout3 = new QGridLayout(colorFrame3, 1, 1, 2);

    useCustomColorBtn3 = new QCheckBox(i18n("Use custom colors"), colorFrame3);
    cLayout3->addMultiCellWidget(useCustomColorBtn3, 1, 1, 0, 3);

    cLayout3->addWidget(new QLabel(i18n("Slider:"), colorFrame3), 2, 0);
    cLayout3->addWidget(new QLabel(i18n("Arrow Button:"), colorFrame3), 2, 1);
    cLayout3->addWidget(new QLabel(i18n("Arrow:"), colorFrame3), 2, 2);
    cLayout3->addWidget(new QLabel(i18n("Groove:"), colorFrame3), 2, 3);

    scrollbarBtn = new KColorButton(colorFrame3);
    cLayout3->addWidget(scrollbarBtn, 3, 0);
    scrollArbBtn = new KColorButton(colorFrame3);
    cLayout3->addWidget(scrollArbBtn, 3, 1);
    scrollAfgBtn = new KColorButton(colorFrame3);
    cLayout3->addWidget(scrollAfgBtn, 3, 2);
    scrollGrvBtn = new KColorButton(colorFrame3);
    cLayout3->addWidget(scrollGrvBtn, 3, 3);

    connect(useCustomColorBtn3, SIGNAL(toggled(bool)), this,
            SLOT(slotUseCustomColor3Clicked(bool)));
    connect(scrollbarBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(scrollArbBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(scrollAfgBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(scrollGrvBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));

    cLayout3->setColStretch(4, 1);
    layout->addWidget(colorGrp3);

    layout->addSpacing(5);

    // Prelight HBox

    QHBox *prelightColorBox = new QHBox(page2);

    //     Pushbutton prelight
    QVGroupBox *colorGrp4 = new QVGroupBox(i18n("Pushbutton prelight"), prelightColorBox);
    QHBox *colorBox4 = new QHBox(colorGrp4);
    useCustomColorBtn4 = new QCheckBox(i18n("Use custom color"), colorBox4);
    connect(useCustomColorBtn4, SIGNAL(toggled(bool)), this,
            SLOT(slotUseCustomColor4Clicked(bool)));
    btnprlBtn = new KColorButton(colorBox4);
    connect(btnprlBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    colorBox4->setStretchFactor(new QWidget(colorBox4), 1);

    prelightInnerCircumOnlyBtn = new QCheckBox(i18n("Only for the inner circumference"), colorGrp4);
    connect(prelightInnerCircumOnlyBtn, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));

    //     Combobox prelight
    QVGroupBox *colorGrpCbx = new QVGroupBox(i18n("Combobox prelight"), prelightColorBox);
    QHBox *colorBoxCbx = new QHBox(colorGrpCbx);
    useCustomColorBtnCbx = new QCheckBox(i18n("Use custom color"), colorBoxCbx);
    connect(useCustomColorBtnCbx, SIGNAL(toggled(bool)), this,
            SLOT(slotUseCustomColorCbxClicked(bool)));
    cbxprlBtn = new KColorButton(colorBoxCbx);
    connect(cbxprlBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    colorBoxCbx->setStretchFactor(new QWidget(colorBoxCbx), 1);

    prelightInnerCircumOnlyCbxBtn = new QCheckBox(i18n("Only for the inner circumference"), colorGrpCbx);
    connect(prelightInnerCircumOnlyCbxBtn, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));

    layout->addWidget(prelightColorBox);

    layout->addSpacing(5);

    // Border colors
    QVGroupBox *colorGrpButtonBorder = new QVGroupBox(i18n("Border Colors"), page2);
    QWidget *colorFrameButtonBorder  = new QWidget(colorGrpButtonBorder);
    QGridLayout *cLayoutButtonBorder = new QGridLayout(colorFrameButtonBorder, 1, 1, 2);

    cLayoutButtonBorder->addMultiCellWidget(new QLabel(i18n("Check widgets which uses the custom color border"), colorFrameButtonBorder),
					    1, 1, 0, 2);

    useButtonBorderColor = new QCheckBox(i18n("Push button"), colorFrameButtonBorder);
    cLayoutButtonBorder->addWidget(useButtonBorderColor, 2, 0);
    useComboboxBorderColor = new QCheckBox(i18n("Combo box"), colorFrameButtonBorder);
    cLayoutButtonBorder->addWidget(useComboboxBorderColor, 3, 0);
    useStatusbarBorderColor = new QCheckBox(i18n("Statusbar"), colorFrameButtonBorder);
    cLayoutButtonBorder->addWidget(useStatusbarBorderColor, 4, 0);

    buttonBorderColBtn = new KColorButton(colorFrameButtonBorder);
    cLayoutButtonBorder->addWidget(buttonBorderColBtn, 2, 1);
    cLayoutButtonBorder->addWidget(new QLabel(i18n("(Other than small buttons)"), colorFrameButtonBorder), 2, 2);

    comboboxBorderColBtn = new KColorButton(colorFrameButtonBorder);
    cLayoutButtonBorder->addWidget(comboboxBorderColBtn, 3, 1);
    cLayoutButtonBorder->addWidget(new QLabel(i18n("(Other than light weight widgets)"), colorFrameButtonBorder), 3, 2);

    statusbarBorderColBtn = new KColorButton(colorFrameButtonBorder);
    cLayoutButtonBorder->addWidget(statusbarBorderColBtn, 4, 1);
    cLayoutButtonBorder->addWidget(new QLabel(i18n("(For the surround borders)"), colorFrameButtonBorder), 4, 2);

    connect(useButtonBorderColor, SIGNAL(toggled(bool)), this,
            SLOT(slotUseButtonBorderColorClicked(bool)));
    connect(useComboboxBorderColor, SIGNAL(toggled(bool)), this,
            SLOT(slotUseComboboxBorderColorClicked(bool)));
    connect(useStatusbarBorderColor, SIGNAL(toggled(bool)), this,
            SLOT(slotUseStatusbarBorderColorClicked(bool)));
    connect(buttonBorderColBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(comboboxBorderColBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(statusbarBorderColBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));

    cLayoutButtonBorder->setColStretch(3, 1);
    layout->addWidget(colorGrpButtonBorder);

    layout->addSpacing(5);

    // Progressbar colors
    QVGroupBox *colorGrp5 = new QVGroupBox(i18n("Progressbar colors"), page2);
    QWidget *colorFrame5  = new QWidget(colorGrp5);
    QGridLayout *cLayout5 = new QGridLayout(colorFrame5, 1, 1, 2);

    useCustomColorBtn5 = new QCheckBox(i18n("Use custom colors"), colorFrame5);
    cLayout5->addMultiCellWidget(useCustomColorBtn5, 1, 1, 0, 3);

    cLayout5->addWidget(new QLabel(i18n("Bar:"), colorFrame5), 2, 0);
    cLayout5->addWidget(new QLabel(i18n("Normal text:"), colorFrame5), 2, 1);
    cLayout5->addWidget(new QLabel(i18n("Highlighted text:"), colorFrame5), 2, 2);

    pgbColorBtn = new KColorButton(colorFrame5);
    cLayout5->addWidget(pgbColorBtn, 3, 0);
    pglColorBtn1 = new KColorButton(colorFrame5);
    cLayout5->addWidget(pglColorBtn1, 3, 1);
    pglColorBtn2 = new KColorButton(colorFrame5);
    cLayout5->addWidget(pglColorBtn2, 3, 2);

    connect(useCustomColorBtn5, SIGNAL(toggled(bool)), this,
            SLOT(slotUseCustomColor5Clicked(bool)));
    connect(pgbColorBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(pglColorBtn1, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));
    connect(pglColorBtn2, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));

    useCustomColorBtn6 = new QCheckBox(i18n("Fill the progressbar groove with the custom color"), colorFrame5);
    cLayout5->addMultiCellWidget(useCustomColorBtn6, 4, 4, 0, 3);
    connect(useCustomColorBtn6, SIGNAL(toggled(bool)), this,
            SLOT(slotUseCustomColor6Clicked(bool)));

    cLayout5->addWidget(new QLabel(i18n("Custom color "), colorFrame5), 5, 0);
    pggColorBtn = new KColorButton(colorFrame5);
    cLayout5->addWidget(pggColorBtn, 5, 1);
    connect(pggColorBtn, SIGNAL(changed(const QColor &)), this,
            SLOT(slotBtnColorChanged(const QColor &)));

    cLayout5->setColStretch(3, 1);

    layout->addWidget(colorGrp5);

    layout->addStretch(1);

   //--- tab 3 ---

    QWidget *page3 = new QWidget(tabWidget);
    layout = new QVBoxLayout(page3);
    layout->addSpacing(5);

    tabWidget->insertTab(page3, i18n("Extra Options"));

    // Extra Options
    QVGroupBox *extraGrp2 = new QVGroupBox(i18n("Extra Options"), page3);
    animateProgressBar = new QCheckBox(i18n("Animate progress bars"), extraGrp2);
    useFlb = new QCheckBox(i18n("Use flat bevel buttons"), extraGrp2);
    usePbcBvl = new QCheckBox(i18n("Use pushbutton color for bevel buttons"), extraGrp2);
    useBGCTab = new QCheckBox(i18n("Use background color for tabs"), extraGrp2);
    highlightDefaultButton = new QCheckBox(i18n("Highlight default buttons"), extraGrp2);
    highlightActiveTask = new QCheckBox(i18n("Highlight the active taskbar button with the active tabline color"), extraGrp2);
    flattenActiveTab = new QCheckBox(i18n("Flatten active tab (Top tab only)"), extraGrp2);
    surroundSunkenPanel = new QCheckBox(i18n("Surround the sunken panels and the statusbars with dark borders"), extraGrp2);
    surroundTaskbutton = new QCheckBox(i18n("Surround the taskbar buttons with dark borders"), extraGrp2);
    reduceButtonSize = new QCheckBox(i18n("Reduce pushbutton size"), extraGrp2);
    barBorderFollowsContrast = new QCheckBox(i18n("Border's thickness of menubar and toolbar follows contrast"), extraGrp2);
    removeSublineArea = new QCheckBox(i18n("Remove \"subtract-line\" area from \"add-line\" button of scrollbar"), extraGrp2);

    connect(animateProgressBar, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(useFlb, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(usePbcBvl, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(useBGCTab, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(highlightDefaultButton, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(highlightActiveTask, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(flattenActiveTab, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(surroundSunkenPanel, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(surroundTaskbutton, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(reduceButtonSize, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(barBorderFollowsContrast, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(removeSublineArea, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));

    layout->addWidget(extraGrp2);

    layout->addStretch(1);

    //--- tab Others ---

    QWidget *pageOthers = new QWidget(tabWidget);
    layout = new QVBoxLayout(pageOthers);
    layout->addSpacing(5);

    tabWidget->insertTab(pageOthers, i18n("Others"));

    // Use Shadowed Text
    QVGroupBox *otherGrp1 = new QVGroupBox(i18n("Use Shadowed Text"), pageOthers);
    useShdM = new QCheckBox(i18n("Menu"), otherGrp1);

    QHBox *dsbShdBox = new QHBox(otherGrp1);
    QLabel *dsbShdLblDmy = new QLabel("     ", dsbShdBox);
    disableShdEmpBtn = new QCheckBox(i18n("Disable emphasis of the selected menu item's shadow"), dsbShdBox);

    useShdMB = new QCheckBox(i18n("Menubar"), otherGrp1);
    useShdB = new QCheckBox(i18n("Push button"), otherGrp1);
    useShdT = new QCheckBox(i18n("Tab"), otherGrp1);

    connect(useShdM, SIGNAL(toggled(bool)), this,
            SLOT(slotUseShadowMClicked(bool)));
    connect(disableShdEmpBtn, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(useShdMB, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(useShdB, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(useShdT, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));

    dsbShdBox->setStretchFactor(new QWidget(dsbShdBox), 1);
    layout->addWidget(otherGrp1);
    layout->addSpacing(5);

    // Strong Gradation
    QVGroupBox *otherGrpSg = new QVGroupBox(i18n("Strong gradation"), pageOthers);
    useSgb  = new QCheckBox(i18n("Use strong gradation for push buttons(other than small buttons)"), otherGrpSg);
    useSgbv = new QCheckBox(i18n("Use strong gradation for bevel buttons"), otherGrpSg);
    useSgc  = new QCheckBox(i18n("Use strong gradation for comboboxes"), otherGrpSg);

    connect(useSgb, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(useSgbv, SIGNAL(toggled(bool)), this,
            SLOT(slotUseSgbvClicked(bool)));
    connect(useSgc, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));

    layout->addWidget(otherGrpSg);

    layout->addSpacing(5);

    // Light weight widgets
    QVGroupBox *otherGrp2 = new QVGroupBox(i18n("Light weight widgets"), pageOthers);
    QLabel *lwwLblDmy = new QLabel("Check widgets which you want to make light weight", otherGrp2);
    useLightCombo = new QCheckBox(i18n("Editable comboboxes"), otherGrp2);
    useLightNECombo = new QCheckBox(i18n("Standard comboboxes"), otherGrp2);

    connect(useLightCombo, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(useLightNECombo, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));

    layout->addWidget(otherGrp2);

    layout->addSpacing(5);

    //Features to disable
    QVGroupBox *otherGrp3 = new QVGroupBox(i18n("Features to disable"), pageOthers);
    disableBB = new QCheckBox(i18n("Disable border of menubars and toolbars"), otherGrp3);
    disableScrollbarBorder = new QCheckBox(i18n("Disable border of scrollbar grooves"), otherGrp3);
    useSingleLineHandles = new QCheckBox(i18n("Disable 2nd line of toolbar handles and applet handles"), otherGrp3);
    useShadowlessButton = new QCheckBox(i18n("Disable shadow of pushbuttons and comboboxes"), otherGrp3);
    disableKMenuTitles = new QCheckBox(i18n("Disable KMenu Titles(This setting is effective in other styles too)"), otherGrp3);

    connect(disableBB, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(disableScrollbarBorder, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(useSingleLineHandles, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(useShadowlessButton, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));
    connect(disableKMenuTitles, SIGNAL(toggled(bool)), this,
            SLOT(slotCheckBtnClicked(bool)));

    layout->addWidget(otherGrp3);

    layout->addStretch(1);

   //--- tab Scheme ---

    QWidget *pageScheme = new QWidget(tabWidget);
    layout = new QVBoxLayout(pageScheme);
    layout->addSpacing(5);
    tabWidget->insertTab(pageScheme, i18n("Scheme"));

    // Scheme
    QVGroupBox *scmGrp = new QVGroupBox(i18n("Config Scheme"), pageScheme);
    QLabel *schemeDmyLbl1 = new QLabel(i18n("\nThe config scheme is saved at"), scmGrp);
    QLabel *schemeDmyLbl2 = new QLabel(i18n("   \"$HOME/.qt/thinkeramik_<scheme name>.kcmrc\" file."), scmGrp);
    QLabel *schemeDmyLbl3 = new QLabel(i18n("   The characters which can be used for a scheme name are"), scmGrp);
    QLabel *schemeDmyLbl4 = new QLabel(i18n("   small letters of the alphabet, all digits, \"-\", and \"_\".\n"), scmGrp);

    QHBox *scmBox = new QHBox(scmGrp);
    QLabel *schemeLbl = new QLabel(i18n("Scheme Name:"), scmBox);
    schemeName = new QLineEdit(scmBox);
    loadSchemeBtn = new QPushButton(i18n("Load"),scmBox);
    saveSchemeBtn = new QPushButton(i18n("Save"),scmBox);
    delSchemeBtn = new QPushButton(i18n("Delete"),scmBox);
    scmBox->setStretchFactor(new QWidget(scmBox), 1);

    schemeListBox = new QListBox(scmGrp);
    schemeListBox->setMinimumSize(100,120);

    QLabel *schemeDmyLbl11 = new QLabel(i18n("\nScheme manager can also read the global scheme files."), scmGrp);
    QLabel *schemeDmyLbl12 = new QLabel(i18n("\"Global scheme file\" means the scheme files stored in"), scmGrp);
    QLabel *schemeDmyLbl13 = new QLabel(i18n("   \"$KDEDIR/share/apps/kdisplay/styleconfs\" directory."), scmGrp);
    QLabel *schemeDmyLbl14 = new QLabel(i18n("The global file is ignored when the same name files exist"), scmGrp);
    QLabel *schemeDmyLbl15 = new QLabel(i18n("   in both $HOME/.qt and the global directory."), scmGrp);

    connect(loadSchemeBtn, SIGNAL(clicked()), this,
            SLOT(slotLoadScheme()));
    connect(saveSchemeBtn, SIGNAL(clicked()), this,
            SLOT(slotSaveScheme()));
    connect(delSchemeBtn, SIGNAL(clicked()), this,
            SLOT(slotDelScheme()));
    connect(schemeListBox, SIGNAL(clicked(QListBoxItem *)), this,
            SLOT(slotSchemeListClicked(QListBoxItem *)));
    connect(schemeListBox, SIGNAL(selectionChanged(QListBoxItem *)), this,
            SLOT(slotSchemeListClicked(QListBoxItem *)));

    layout->addWidget(scmGrp);
    layout->addStretch(1);

    loadSettings("/qt", false);
    searchScheme();

    menuFgBtn->setEnabled(useCustomColorBtn1->isOn());
    menuBgBtn->setEnabled(useCustomColorBtn1->isOn());
    menuStripeBtn->setEnabled(useCustomColorBtn1->isOn());
    menuSeparatorBtn->setEnabled(useCustomColorBtn1->isOn());

    customGradBtn->setEnabled(enableGradBtn->isOn());

    borderColBtn->setEnabled(useCustomColorBtn1b->isOn());

    menuSelFgBtn->setEnabled(useCustomColorBtn1c->isOn());
    menuSelBgBtn->setEnabled(useCustomColorBtn1c->isOn());
    menuSelShdBtn->setEnabled(useCustomColorBtn1c->isOn());

    menubgfile->setEnabled(useMenuBGI->isOn());
    menubgBrowse->setEnabled(useMenuBGI->isOn());
    scaledMenuBGI->setEnabled(useMenuBGI->isOn());

    strong3dmi->setEnabled(enableMI3d->isOn());
    strong3dms->setEnabled(enableMS3d->isOn());

    activeTabBtn->setEnabled(useCustomColorBtn2->isOn() && !disableUpperLinesBtn->isOn());
    useCustomColorBtn2->setEnabled(!disableUpperLinesBtn->isOn());

    scrollbarBtn->setEnabled(useCustomColorBtn3->isOn());
    scrollArbBtn->setEnabled(useCustomColorBtn3->isOn());
    scrollAfgBtn->setEnabled(useCustomColorBtn3->isOn());
    scrollGrvBtn->setEnabled(useCustomColorBtn3->isOn());

    btnprlBtn->setEnabled(useCustomColorBtn4->isOn());
    prelightInnerCircumOnlyBtn->setEnabled(useCustomColorBtn4->isOn());

    cbxprlBtn->setEnabled(useCustomColorBtnCbx->isOn());
    prelightInnerCircumOnlyCbxBtn->setEnabled(useCustomColorBtnCbx->isOn());

    buttonBorderColBtn->setEnabled(useButtonBorderColor->isOn());
    comboboxBorderColBtn->setEnabled(useComboboxBorderColor->isOn());
    statusbarBorderColBtn->setEnabled(useStatusbarBorderColor->isOn());

    pgbColorBtn->setEnabled(useCustomColorBtn5->isOn());
    pglColorBtn1->setEnabled(useCustomColorBtn5->isOn());
    pglColorBtn2->setEnabled(useCustomColorBtn5->isOn());

    pggColorBtn->setEnabled(useCustomColorBtn6->isOn());

    disableShdEmpBtn->setEnabled(useShdM->isOn());

    schemeName->setEnabled(true);
    loadSchemeBtn->setEnabled(true);
    saveSchemeBtn->setEnabled(true);
    delSchemeBtn->setEnabled(true);

    schemeListBox->setEnabled(true);
}

void ThinKeramikStyleConfig::loadSettings(const QString &searchPath, bool globalScheme)
{
    QSettings settings;

    if (globalScheme) {
          settings.insertSearchPath( QSettings::Unix, QString(getenv("KDEDIR")) + "/share/apps/kdisplay/styleconfs" );
    }

    QString mfgcolstr = settings.readEntry(searchPath + "/ThinKmk/MenuFG");
    QString mbgcolstr = settings.readEntry(searchPath + "/ThinKmk/MenuBG");
    QString mstcolstr = settings.readEntry(searchPath + "/ThinKmk/MenuStripe");
    QString menuSepColStr = settings.readEntry(searchPath + "/ThinKmk/MenuSeparator");

    if (!mbgcolstr.isNull()) {
          useCustomColorBtn1->setChecked(true);
          menuFgBtn->setColor(QColor(mfgcolstr));
	  menuBgBtn->setColor(QColor(mbgcolstr));
	  menuStripeBtn->setColor(QColor(mstcolstr));
	  if (menuSepColStr.isNull()) {
	          menuSeparatorBtn->setColor(QColor(mbgcolstr).dark(133));
	  } else {
	          menuSeparatorBtn->setColor(QColor(menuSepColStr));
	  }
    } else {
          useCustomColorBtn1->setChecked(false);
	  menuFgBtn->setColor(colorGroup().text());
	  menuBgBtn->setColor(colorGroup().background().light(110));
	  menuStripeBtn->setColor(colorGroup().mid());
	  menuSeparatorBtn->setColor(colorGroup().background().dark(133));
    }

    enableGradBtn->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/EnableGradation"));
    customGradBtn->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/CustomGradation"));

    QString mbgifile = settings.readEntry(searchPath + "/ThinKmk/MenuBGImage");
    if (!mbgifile.isNull()) {
          useMenuBGI->setChecked(true);
          menubgfile->setText(mbgifile);
    } else {
          useMenuBGI->setChecked(false);
          menubgfile->setText("");
    }
    scaledMenuBGI->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/ScaledMenuBGImage"));

    QString bordercolstr = settings.readEntry(searchPath + "/ThinKmk/MenuBorder");

    if (!bordercolstr.isNull()) {
          useCustomColorBtn1b->setChecked(true);
	  borderColBtn->setColor(QColor(bordercolstr));
    } else {
          useCustomColorBtn1b->setChecked(false);
	  borderColBtn->setColor(colorGroup().shadow());
    }

    QString mselfgcolstr = settings.readEntry(searchPath + "/ThinKmk/MenuSelectedFG");
    QString mselbgcolstr = settings.readEntry(searchPath + "/ThinKmk/MenuSelectedBG");
    QString mselshdcolstr = settings.readEntry(searchPath + "/ThinKmk/MenuSelectedShadow");

    if (!mselbgcolstr.isNull()) {
          useCustomColorBtn1c->setChecked(true);
          menuSelFgBtn->setColor(QColor(mselfgcolstr));
	  menuSelBgBtn->setColor(QColor(mselbgcolstr));
	  menuSelShdBtn->setColor(QColor(mselshdcolstr));
    } else {
          useCustomColorBtn1c->setChecked(false);
	  menuSelFgBtn->setColor(colorGroup().highlightedText());
	  menuSelBgBtn->setColor(colorGroup().highlight());
	  menuSelShdBtn->setColor(colorGroup().highlight().dark(130));
    }

    strong3dmi->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/Strong3DMI"));
    strong3dms->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/Strong3DMS"));
    enableMI3d->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/EnableMenuItem3D"));
    enableMS3d->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/EnableStripe3D"));

    QString atcolstr = settings.readEntry(searchPath + "/ThinKmk/ActiveTab");

    if (!atcolstr.isNull()) {
          useCustomColorBtn2->setChecked(true);
	  activeTabBtn->setColor(QColor(atcolstr));
    } else {
          useCustomColorBtn2->setChecked(false);
	  activeTabBtn->setColor(colorGroup().highlight());
    }

    disableUpperLinesBtn->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/DisableUpperLines"));

    QString sbcolstr = settings.readEntry(searchPath + "/ThinKmk/Scrollbar");
    QString sacolstr = settings.readEntry(searchPath + "/ThinKmk/ScrollArrowbtn");
    QString safgcolstr = settings.readEntry(searchPath + "/ThinKmk/ScrollArrowFG");
    QString sgcolstr = settings.readEntry(searchPath + "/ThinKmk/ScrollGroove");
    if (sacolstr.isNull() && !sbcolstr.isNull()) {
          sacolstr = sbcolstr;
    }

    if (!sbcolstr.isNull()) {
          // For compatibility from older version.
          QColor safgcol = colorGroup().buttonText();
	  QColor sgcol   = colorGroup().button();
	  if (!safgcolstr.isNull()) {
	        safgcol  = QColor(safgcolstr);
	        sgcol    = QColor(sgcolstr);
	  }

          useCustomColorBtn3->setChecked(true);
	  scrollbarBtn->setColor(QColor(sbcolstr));
	  scrollArbBtn->setColor(QColor(sacolstr));
	  scrollAfgBtn->setColor(safgcol);
	  scrollGrvBtn->setColor(sgcol);
    } else {
          useCustomColorBtn3->setChecked(false);
	  scrollbarBtn->setColor(QColor(settings.readEntry(searchPath + "/KWinPalette/inactiveBackground", "#d8d8d8")));
	  scrollArbBtn->setColor(QColor(settings.readEntry(searchPath + "/KWinPalette/inactiveBackground", "#d8d8d8")));
	  scrollAfgBtn->setColor(colorGroup().buttonText());
	  scrollGrvBtn->setColor(colorGroup().button());
    }

    QString btnprlcolstr = settings.readEntry(searchPath + "/ThinKmk/ButtonPrelight");
    if (!btnprlcolstr.isNull()) {
          useCustomColorBtn4->setChecked(true);
	  btnprlBtn->setColor(QColor(btnprlcolstr));
	  prelightInnerCircumOnlyBtn->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/PrelightInnerCircumOnly"));
    } else {
          useCustomColorBtn4->setChecked(false);
	  btnprlBtn->setColor(colorGroup().button().light(105));
	  prelightInnerCircumOnlyBtn->setChecked(false);
    }

    QString cbxprlcolstr = settings.readEntry(searchPath + "/ThinKmk/ComboboxPrelight");
    if (!cbxprlcolstr.isNull()) {
          useCustomColorBtnCbx->setChecked(true);
	  cbxprlBtn->setColor(QColor(cbxprlcolstr));
	  prelightInnerCircumOnlyCbxBtn->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/PrelightInnerCircumOnlyCombobox"));
    } else {
          useCustomColorBtnCbx->setChecked(false);
	  cbxprlBtn->setColor(colorGroup().button().light(105));
	  prelightInnerCircumOnlyCbxBtn->setChecked(false);
    }

    QString buttonBorderColStr = settings.readEntry(searchPath + "/ThinKmk/ButtonBorderColor");
    if (!buttonBorderColStr.isNull()) {
          useButtonBorderColor->setChecked(true);
	  buttonBorderColBtn->setColor(QColor(buttonBorderColStr));
    } else {
          useButtonBorderColor->setChecked(false);
	  buttonBorderColBtn->setColor(colorGroup().button().dark(130));
    }

    QString comboboxBorderColStr = settings.readEntry(searchPath + "/ThinKmk/ComboboxBorderColor");
    if (!comboboxBorderColStr.isNull()) {
          useComboboxBorderColor->setChecked(true);
	  comboboxBorderColBtn->setColor(QColor(comboboxBorderColStr));
    } else {
          useComboboxBorderColor->setChecked(false);
	  comboboxBorderColBtn->setColor(colorGroup().button().dark(130));
    }

    QString statusbarBorderColStr = settings.readEntry(searchPath + "/ThinKmk/StatusbarBorderColor");
    if (!statusbarBorderColStr.isNull()) {
          useStatusbarBorderColor->setChecked(true);
	  statusbarBorderColBtn->setColor(QColor(statusbarBorderColStr));
    } else {
          useStatusbarBorderColor->setChecked(false);
	  statusbarBorderColBtn->setColor(colorGroup().button().dark(145));
    }

    QString pgbColor  = settings.readEntry(searchPath + "/ThinKmk/ProgressbarColor");
    QString pglColor1 = settings.readEntry(searchPath + "/ThinKmk/ProgressbarLabelColor1");
    QString pglColor2 = settings.readEntry(searchPath + "/ThinKmk/ProgressbarLabelColor2");
    if (!pgbColor.isNull()) {
          useCustomColorBtn5->setChecked(true);
	  pgbColorBtn->setColor(QColor(pgbColor));
	  pglColorBtn1->setColor(QColor(pglColor1));
	  pglColorBtn2->setColor(QColor(pglColor2));
    } else {
          useCustomColorBtn5->setChecked(false);
	  pgbColorBtn->setColor(colorGroup().highlight());
	  pglColorBtn1->setColor(colorGroup().text());
	  pglColorBtn2->setColor(colorGroup().highlightedText());
    }

    QString pggColor  = settings.readEntry(searchPath + "/ThinKmk/ProgressbarGrooveColor");
    if (!pggColor.isNull()) {
          useCustomColorBtn6->setChecked(true);
	  pggColorBtn->setColor(QColor(pggColor));
    } else {
          useCustomColorBtn6->setChecked(false);
	  pggColorBtn->setColor(colorGroup().base());
    }

    useShdM->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseShadowTextMenu"));
    disableShdEmpBtn->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/DisableShadowEmphasis"));
    useShdMB->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseShadowTextMenuBar"));
    useShdB->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseShadowTextButton"));
    useShdT->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseShadowTextTab"));

    animateProgressBar->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/animateProgressBar"));

    useSgb->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseSGButton"));

    useSgc->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseSGCombobox"));

    useFlb->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseFlatBevel"));

    if (useFlb->isOn()) {
            useSgbv->setChecked(false);
    } else {
            useSgbv->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseSGBevel", useSgb->isOn()));
    }

    usePbcBvl->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UsePBCBevel"));

    highlightDefaultButton->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/HighlightDefaultButton"));

    highlightActiveTask->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/HighlightActiveTask"));

    flattenActiveTab->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/FlattenActiveTab"));

    surroundSunkenPanel->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/SurroundSunkenPanel"));

    surroundTaskbutton->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/SurroundTaskbutton"));

    reduceButtonSize->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/ReduceButtonSize"));

    barBorderFollowsContrast->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/BarBorderFollowsContrast"));

    removeSublineArea->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/RemoveSublineArea"));

    useLightCombo->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseLightWeightCombobox"));

    useLightNECombo->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseLightWeightStdCombobox"));

    disableBB->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/DisableBarBorder"));

    useBGCTab->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseBGColorTab"));

    useSingleLineHandles->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseSingleLineHandles"));

    disableScrollbarBorder->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/DisableScrollbarBorder"));

    useShadowlessButton->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/UseShadowlessButton"));

    if (qstrcmp(searchPath, "/qt") == 0) {
            disableKMenuTitlesOld = !loadKickerConfig();
	    disableKMenuTitles->setChecked(disableKMenuTitlesOld);
    } else {
            disableKMenuTitles->setChecked(settings.readBoolEntry(searchPath + "/ThinKmk/DisableKMenuTitles"));
    }

    slotUseCustomColor1Clicked(useCustomColorBtn1->isChecked());
    slotUseCustomColor1bClicked(useCustomColorBtn1b->isChecked());
    slotUseCustomColor1cClicked(useCustomColorBtn1c->isChecked());
    slotUseMenuBGIClicked(useMenuBGI->isChecked());
    slotEnable3DMIBtnClicked(enableMI3d->isChecked());
    slotEnable3DMSBtnClicked(enableMS3d->isChecked());
    slotEnableGradClicked(enableGradBtn->isChecked());
    slotUseCustomColor2Clicked(useCustomColorBtn2->isChecked());
    slotDisableUpperLinesClicked(disableUpperLinesBtn->isChecked());
    slotUseCustomColor3Clicked(useCustomColorBtn3->isChecked());
    slotUseCustomColor4Clicked(useCustomColorBtn4->isChecked());
    slotUseCustomColorCbxClicked(useCustomColorBtnCbx->isChecked());
    slotUseCustomColor5Clicked(useCustomColorBtn5->isChecked());
    slotUseCustomColor6Clicked(useCustomColorBtn6->isChecked());
    slotUseButtonBorderColorClicked(useButtonBorderColor->isChecked());
    slotUseComboboxBorderColorClicked(useComboboxBorderColor->isChecked());
    slotUseStatusbarBorderColorClicked(useStatusbarBorderColor->isChecked());
    slotUseShadowMClicked(useShdM->isChecked());
    slotBtnColorChanged(colorGroup().background());
    slotUseSgbvClicked(useSgbv->isChecked());

}

bool ThinKeramikStyleConfig::loadKickerConfig() {
    KConfig c("kickerrc", false, false);
    c.setGroup("menus");
    return c.readBoolEntry( "ShowMenuTitles", true );
}

ThinKeramikStyleConfig::~ThinKeramikStyleConfig()
{
    KGlobal::locale()->removeCatalogue("kstyle_thinkeramik_config");
}


void ThinKeramikStyleConfig::save()
{
    saveSettings("/qt");
}

void ThinKeramikStyleConfig::saveSettings(const QString &searchPath)
{
    QSettings *settings = new QSettings;
    QString aValue;

    if(useCustomColorBtn1->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/MenuFG",  "#" + aValue.sprintf("%06x",
                             (menuFgBtn->color().red()*65536 + menuFgBtn->color().green()*256 + menuFgBtn->color().blue())) );
        settings->writeEntry(searchPath + "/ThinKmk/MenuBG",  "#" + aValue.sprintf("%06x",
                             (menuBgBtn->color().red()*65536 + menuBgBtn->color().green()*256 + menuBgBtn->color().blue())) );
        settings->writeEntry(searchPath + "/ThinKmk/MenuStripe", "#" +  aValue.sprintf("%06x",
			     (menuStripeBtn->color().red()*65536 + menuStripeBtn->color().green()*256 + menuStripeBtn->color().blue())) );
        settings->writeEntry(searchPath + "/ThinKmk/MenuSeparator", "#" +  aValue.sprintf("%06x",
			     (menuSeparatorBtn->color().red()*65536 + menuSeparatorBtn->color().green()*256 + menuSeparatorBtn->color().blue())) );
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/MenuFG",QString::null);
        settings->writeEntry(searchPath + "/ThinKmk/MenuBG",QString::null);
        settings->writeEntry(searchPath + "/ThinKmk/MenuStripe",QString::null);
        settings->writeEntry(searchPath + "/ThinKmk/MenuSeparator",QString::null);
    }

    settings->writeEntry(searchPath + "/ThinKmk/EnableGradation", enableGradBtn->isOn());
    if (enableGradBtn->isOn()) {
        settings->writeEntry(searchPath + "/ThinKmk/CustomGradation", customGradBtn->isOn());
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/CustomGradation",QString::null);
    }

    if (useMenuBGI->isOn()) {
        settings->writeEntry(searchPath + "/ThinKmk/MenuBGImage", menubgfile->text());
        settings->writeEntry(searchPath + "/ThinKmk/ScaledMenuBGImage", scaledMenuBGI->isOn());
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/MenuBGImage",QString::null);
        settings->writeEntry(searchPath + "/ThinKmk/ScaledMenuBGImage",QString::null);
    }

    if(useCustomColorBtn1b->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/MenuBorder", "#" + aValue.sprintf("%06x",
			     (borderColBtn->color().red()*65536 + borderColBtn->color().green()*256 + borderColBtn->color().blue())) );
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/MenuBorder",QString::null);
    }


    if(useCustomColorBtn1c->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/MenuSelectedFG",  "#" + aValue.sprintf("%06x",
                             (menuSelFgBtn->color().red()*65536 + menuSelFgBtn->color().green()*256 + menuSelFgBtn->color().blue())) );
        settings->writeEntry(searchPath + "/ThinKmk/MenuSelectedBG",  "#" + aValue.sprintf("%06x",
                             (menuSelBgBtn->color().red()*65536 + menuSelBgBtn->color().green()*256 + menuSelBgBtn->color().blue())) );
        settings->writeEntry(searchPath + "/ThinKmk/MenuSelectedShadow", "#" +  aValue.sprintf("%06x",
			     (menuSelShdBtn->color().red()*65536 + menuSelShdBtn->color().green()*256 + menuSelShdBtn->color().blue())) );
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/MenuSelectedFG",QString::null);
        settings->writeEntry(searchPath + "/ThinKmk/MenuSelectedBG",QString::null);
        settings->writeEntry(searchPath + "/ThinKmk/MenuSelectedShadow",QString::null);
    }

    settings->writeEntry(searchPath + "/ThinKmk/Strong3DMI", strong3dmi->isOn());
    settings->writeEntry(searchPath + "/ThinKmk/Strong3DMS", strong3dms->isOn());
    settings->writeEntry(searchPath + "/ThinKmk/EnableMenuItem3D", enableMI3d->isOn());
    settings->writeEntry(searchPath + "/ThinKmk/EnableStripe3D", enableMS3d->isOn());

    if(useCustomColorBtn2->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/ActiveTab", "#" + aValue.sprintf("%06x",
			     (activeTabBtn->color().red()*65536 + activeTabBtn->color().green()*256 + activeTabBtn->color().blue())) );
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/ActiveTab",QString::null);
    }

    settings->writeEntry(searchPath + "/ThinKmk/DisableUpperLines", disableUpperLinesBtn->isOn());

    if(useCustomColorBtn3->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/Scrollbar", "#" + aValue.sprintf("%06x",
			     (scrollbarBtn->color().red()*65536 + scrollbarBtn->color().green()*256 + scrollbarBtn->color().blue())) );
        settings->writeEntry(searchPath + "/ThinKmk/ScrollArrowbtn", "#" + aValue.sprintf("%06x",
			     (scrollArbBtn->color().red()*65536 + scrollArbBtn->color().green()*256 + scrollArbBtn->color().blue())) );
        settings->writeEntry(searchPath + "/ThinKmk/ScrollArrowFG", "#" + aValue.sprintf("%06x",
			     (scrollAfgBtn->color().red()*65536 + scrollAfgBtn->color().green()*256 + scrollAfgBtn->color().blue())) );
        settings->writeEntry(searchPath + "/ThinKmk/ScrollGroove", "#" + aValue.sprintf("%06x",
			     (scrollGrvBtn->color().red()*65536 + scrollGrvBtn->color().green()*256 + scrollGrvBtn->color().blue())) );
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/Scrollbar",QString::null);
        settings->writeEntry(searchPath + "/ThinKmk/ScrollArrowbtn",QString::null);
        settings->writeEntry(searchPath + "/ThinKmk/ScrollArrowFG",QString::null);
        settings->writeEntry(searchPath + "/ThinKmk/ScrollGroove",QString::null);
    }

    if(useCustomColorBtn4->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/ButtonPrelight", "#" + aValue.sprintf("%06x",
			     (btnprlBtn->color().red()*65536 + btnprlBtn->color().green()*256 + btnprlBtn->color().blue())) );
	settings->writeEntry(searchPath + "/ThinKmk/PrelightInnerCircumOnly", prelightInnerCircumOnlyBtn->isOn());
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/ButtonPrelight",QString::null);
	settings->writeEntry(searchPath + "/ThinKmk/PrelightInnerCircumOnly",QString::null);
    }

    if(useCustomColorBtnCbx->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/ComboboxPrelight", "#" + aValue.sprintf("%06x",
			     (cbxprlBtn->color().red()*65536 + cbxprlBtn->color().green()*256 + cbxprlBtn->color().blue())) );
	settings->writeEntry(searchPath + "/ThinKmk/PrelightInnerCircumOnlyCombobox", prelightInnerCircumOnlyCbxBtn->isOn());
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/ComboboxPrelight",QString::null);
	settings->writeEntry(searchPath + "/ThinKmk/PrelightInnerCircumOnlyCombobox",QString::null);
    }

    if(useButtonBorderColor->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/ButtonBorderColor", "#" + aValue.sprintf("%06x",
			     (buttonBorderColBtn->color().red()*65536 + buttonBorderColBtn->color().green()*256 + buttonBorderColBtn->color().blue())) );
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/ButtonBorderColor",QString::null);
    }

    if(useComboboxBorderColor->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/ComboboxBorderColor", "#" + aValue.sprintf("%06x",
			     (comboboxBorderColBtn->color().red()*65536 + comboboxBorderColBtn->color().green()*256 + comboboxBorderColBtn->color().blue())) );
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/ComboboxBorderColor",QString::null);
    }

    if(useStatusbarBorderColor->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/StatusbarBorderColor", "#" + aValue.sprintf("%06x",
			     (statusbarBorderColBtn->color().red()*65536 + statusbarBorderColBtn->color().green()*256 + statusbarBorderColBtn->color().blue())) );
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/StatusbarBorderColor",QString::null);
    }

    if(useCustomColorBtn5->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/ProgressbarColor", "#" + aValue.sprintf("%06x",
			     (pgbColorBtn->color().red()*65536 + pgbColorBtn->color().green()*256 + pgbColorBtn->color().blue())) );
        settings->writeEntry(searchPath + "/ThinKmk/ProgressbarLabelColor1", "#" + aValue.sprintf("%06x",
			     (pglColorBtn1->color().red()*65536 + pglColorBtn1->color().green()*256 + pglColorBtn1->color().blue())) );
        settings->writeEntry(searchPath + "/ThinKmk/ProgressbarLabelColor2", "#" + aValue.sprintf("%06x",
			     (pglColorBtn2->color().red()*65536 + pglColorBtn2->color().green()*256 + pglColorBtn2->color().blue())) );
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/ProgressbarColor",QString::null);
        settings->writeEntry(searchPath + "/ThinKmk/ProgressbarLabelColor1",QString::null);
        settings->writeEntry(searchPath + "/ThinKmk/ProgressbarLabelColor2",QString::null);
    }

    if(useCustomColorBtn6->isOn()){
        settings->writeEntry(searchPath + "/ThinKmk/ProgressbarGrooveColor", "#" + aValue.sprintf("%06x",
			     (pggColorBtn->color().red()*65536 + pggColorBtn->color().green()*256 + pggColorBtn->color().blue())) );
    } else {
        settings->writeEntry(searchPath + "/ThinKmk/ProgressbarGrooveColor",QString::null);
    }

    settings->writeEntry(searchPath + "/ThinKmk/UseShadowTextMenu", useShdM->isOn());
    settings->writeEntry(searchPath + "/ThinKmk/DisableShadowEmphasis", disableShdEmpBtn->isOn());
    settings->writeEntry(searchPath + "/ThinKmk/UseShadowTextMenuBar", useShdMB->isOn());
    settings->writeEntry(searchPath + "/ThinKmk/UseShadowTextButton", useShdB->isOn());
    settings->writeEntry(searchPath + "/ThinKmk/UseShadowTextTab", useShdT->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/animateProgressBar", animateProgressBar->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/UseSGButton", useSgb->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/UseSGBevel", useSgbv->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/UseSGCombobox", useSgc->isOn());

    if (useSgbv->isOn()) {
            settings->writeEntry(searchPath + "/ThinKmk/UseFlatBevel", false);
    } else {
            settings->writeEntry(searchPath + "/ThinKmk/UseFlatBevel", useFlb->isOn());
    }

    settings->writeEntry(searchPath + "/ThinKmk/UsePBCBevel", usePbcBvl->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/HighlightDefaultButton", highlightDefaultButton->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/HighlightActiveTask", highlightActiveTask->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/FlattenActiveTab", flattenActiveTab->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/SurroundSunkenPanel", surroundSunkenPanel->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/SurroundTaskbutton", surroundTaskbutton->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/ReduceButtonSize", reduceButtonSize->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/BarBorderFollowsContrast", barBorderFollowsContrast->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/RemoveSublineArea", removeSublineArea->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/UseLightWeightCombobox", useLightCombo->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/UseLightWeightStdCombobox", useLightNECombo->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/DisableBarBorder", disableBB->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/UseBGColorTab", useBGCTab->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/UseSingleLineHandles", useSingleLineHandles->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/DisableScrollbarBorder", disableScrollbarBorder->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/UseShadowlessButton", useShadowlessButton->isOn());

    settings->writeEntry(searchPath + "/ThinKmk/DisableKMenuTitles", disableKMenuTitles->isOn());
 
    delete settings; // force sync

    if (qstrcmp(searchPath, "/qt") == 0) {
            saveKickerConfig("kickerrc", !disableKMenuTitles->isOn());
	    QString kdeConfigDir = QDir::homeDirPath() + "/.kde/share/config/";
	    for (int sn=0; sn<10; sn++) {
	            QString screenrc = QString("kicker-screen-%1rc").arg(sn);
		    if (QFile::exists(kdeConfigDir + screenrc)) {
		            saveKickerConfig(screenrc, !disableKMenuTitles->isOn());
		    }
	    }
	    if (disableKMenuTitlesOld != disableKMenuTitles->isOn()) {
	            QByteArray data;
		    kapp->dcopClient()->send( "kicker", "Panel", "restart()", data );
	    }
    }
}

void ThinKeramikStyleConfig::saveKickerConfig(const QString &kickerrc, bool showMenuTitles) {
    KConfig c(kickerrc, false, false);
    c.setGroup("menus");
    c.writeEntry( "ShowMenuTitles", showMenuTitles );
    c.sync();
}

void ThinKeramikStyleConfig::defaults()
{
    loadSettings("/thinkeramik_default.kcm", false);
    emit changed(true);
}

void ThinKeramikStyleConfig::updateChanged()
{
}

void ThinKeramikStyleConfig::slotBtnColorChanged(const QColor &)
{
    emit changed(true);
}

void ThinKeramikStyleConfig::slotCheckBtnClicked(bool en)
{
    emit changed(true);
}

void ThinKeramikStyleConfig::slotTextChanged(const QString &)
{
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseCustomColor1Clicked(bool en)
{
    menuFgBtn->setEnabled(en);
    menuBgBtn->setEnabled(en);
    menuStripeBtn->setEnabled(en);
    menuSeparatorBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseCustomColor1bClicked(bool en)
{
    borderColBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseCustomColor1cClicked(bool en)
{
    menuSelFgBtn->setEnabled(en);
    menuSelBgBtn->setEnabled(en);
    menuSelShdBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseMenuBGIClicked(bool en)
{
    menubgfile->setEnabled(en);
    menubgBrowse->setEnabled(en);
    scaledMenuBGI->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotMenuBGIBrowser()
{
    QString findStartDir = menubgfile->text();
    if (findStartDir.isNull()) {
          findStartDir = QDir::homeDirPath();
    } else if (findStartDir.length() == 0) {
          findStartDir = QDir::homeDirPath();
    }

    QString mbgifile = KFileDialog::getOpenFileName(
                             findStartDir,
			     "Images (*.png *.xpm *.jpg *.bmp *.PNG *.XPM *.JPG *.BMP)",
			     this,
			     "Select menu background" );

    if (!mbgifile.isNull()) {
          menubgfile->setText(mbgifile);
    }
    emit changed(true);
}

void ThinKeramikStyleConfig::slotEnable3DMIBtnClicked(bool en)
{
    strong3dmi->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotEnable3DMSBtnClicked(bool en)
{
    strong3dms->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotEnableGradClicked(bool en)
{
    customGradBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseCustomColor2Clicked(bool en)
{
    activeTabBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotDisableUpperLinesClicked(bool en)
{
    useCustomColorBtn2->setEnabled(!en);
    activeTabBtn->setEnabled(useCustomColorBtn2->isOn() && !disableUpperLinesBtn->isOn());
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseCustomColor3Clicked(bool en)
{
    scrollbarBtn->setEnabled(en);
    scrollArbBtn->setEnabled(en);
    scrollAfgBtn->setEnabled(en);
    scrollGrvBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseCustomColor4Clicked(bool en)
{
    btnprlBtn->setEnabled(en);
    prelightInnerCircumOnlyBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseCustomColorCbxClicked(bool en)
{
    cbxprlBtn->setEnabled(en);
    prelightInnerCircumOnlyCbxBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseButtonBorderColorClicked(bool en)
{
    buttonBorderColBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseComboboxBorderColorClicked(bool en)
{
    comboboxBorderColBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseStatusbarBorderColorClicked(bool en)
{
    statusbarBorderColBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseCustomColor5Clicked(bool en)
{
    pgbColorBtn->setEnabled(en);
    pglColorBtn1->setEnabled(en);
    pglColorBtn2->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseCustomColor6Clicked(bool en)
{
    pggColorBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotUseShadowMClicked(bool en)
{
    disableShdEmpBtn->setEnabled(en);
    emit changed(true);
}

void ThinKeramikStyleConfig::slotLoadScheme()
{
    QString schemeNameText = schemeName->text();
    bool globalScheme = false;

    if (schemeNameText.startsWith("(GLOBAL)")) {
          schemeNameText.remove( 0, 8 );
	  globalScheme = true;
    }

    QString schemeStr  = "/thinkeramik_" + schemeNameText + ".kcm";
    QStringList schemeFile( (QString) (QDir::homeDirPath() + "/.qt" + schemeStr + "rc"));
    schemeFile << (QString) (QString(getenv("KDEDIR")) + "/share/apps/kdisplay/styleconfs" + schemeStr + "rc");
    bool schemeExists = false;
    for ( QStringList::Iterator it = schemeFile.begin(); it != schemeFile.end(); ++it ) {
	if (QFile::exists(*it)) {
	    schemeExists = true;
	    int loadOK = QMessageBox::question(this,
					       i18n("Load Scheme? - Thin Keramik Scheme Manager"),
					       i18n("Do you load \"%1\"?").arg(schemeName->text()) + "\n"
					       + i18n("Current settings will be overwritten."),
					       QMessageBox::Yes,
					       QMessageBox::No,
					       QMessageBox::NoButton);
	    if (loadOK == QMessageBox::Yes) {
	        loadSettings(schemeStr, globalScheme);
		QMessageBox::information(this,
					 i18n("Information - Thin Keramik Scheme Manager"),
					 i18n("\"%1\" was loaded.").arg(schemeName->text()),
					 QMessageBox::Ok,
					 QMessageBox::NoButton,
					 QMessageBox::NoButton);
		emit changed(true);
	    }
	    break;
	}
    }
    if (!schemeExists) {
        QMessageBox::critical(this,
			      i18n("Error - Thin Keramik Scheme Manager"),
			      i18n("\"%1\" : No such scheme.").arg(schemeName->text()),
			      QMessageBox::Cancel,
			      QMessageBox::NoButton,
			      QMessageBox::NoButton);          
    }

}

void ThinKeramikStyleConfig::slotSaveScheme()
{

    bool globalScheme = false;
    if ((schemeName->text()).startsWith("(GLOBAL)")) {
        globalScheme = true;
    }
    QString schemeStr  = "/thinkeramik_" + schemeName->text() + ".kcm";
    QString schemeFile = QDir::homeDirPath() + "/.qt" + schemeStr + "rc";
    int saveOK = QMessageBox::Yes;
    if (QFile::exists(schemeFile)) {
        saveOK = QMessageBox::question(this,
				       i18n("Overwrite Scheme? - Thin Keramik Scheme Manager"),
				       i18n("A scheme called \"%1\" already exists.").arg(schemeName->text()) + "\n"
				       + i18n("Do you want to overwrite it?"),
				       QMessageBox::Yes,
				       QMessageBox::No,
				       QMessageBox::NoButton);
    }
    if (saveOK == QMessageBox::Yes) {
        if (schemeName->text().length() > 0 && !globalScheme) {
	    saveSettings(schemeStr);
	}
	searchScheme();
	if (QFile::exists(schemeFile)) {
	    QMessageBox::information(this,
				     i18n("Information - Thin Keramik Scheme Manager"),
				     i18n("\"%1\" was saved.").arg(schemeName->text()),
				     QMessageBox::Ok,
				     QMessageBox::NoButton,
				     QMessageBox::NoButton);
	} else {
	    QMessageBox::critical(this,
				  i18n("Error - Thin Keramik Scheme Manager"),
				  i18n("Save failed.") + "\n"
				  + i18n("The invalid characters may have been used for the scheme name.."),
				  QMessageBox::Cancel,
				  QMessageBox::NoButton,
				  QMessageBox::NoButton);          

	}
    }
}

void ThinKeramikStyleConfig::slotDelScheme()
{

    QString schemeStr  = "/thinkeramik_" + schemeName->text() + ".kcm";
    QString schemeFile = QDir::homeDirPath() + "/.qt" + schemeStr + "rc";
    QFile delFile1(schemeFile);
    if (delFile1.exists()) {
        int delOK = QMessageBox::question(this,
					  i18n("Delete Scheme? - Thin Keramik Scheme Manager"),
					  i18n("A scheme called \"%1\" will be deleted.").arg(schemeName->text()) + "\n"
					  + i18n("Do you continue?"),
					  QMessageBox::Yes,
					  QMessageBox::No,
					  QMessageBox::NoButton);
	if (delOK == QMessageBox::Yes) {
	    delFile1.remove();
	    searchScheme();

	    QFile delFile2(QDir::homeDirPath() + "/.qt/.thinkeramik_" + schemeName->text() + ".kcmrc.lock");

	    if (delFile2.exists()) {
	        delFile2.remove();
	    }

	    QMessageBox::information(this,
				     i18n("Information - Thin Keramik Scheme Manager"),
				     i18n("\"%1\" was deleted.").arg(schemeName->text()),
				     QMessageBox::Ok,
				     QMessageBox::NoButton,
				     QMessageBox::NoButton);
	}
    } else {
        QMessageBox::critical(this,
			      i18n("Error - Thin Keramik Scheme Manager"),
			      i18n("\"%1\" : No such scheme.").arg(schemeName->text()),
			      QMessageBox::Cancel,
			      QMessageBox::NoButton,
			      QMessageBox::NoButton);          
    }
}

void ThinKeramikStyleConfig::slotSchemeListClicked(QListBoxItem *item)
{
      if (item) {
            schemeName->setText(item->text());
      }
}

void ThinKeramikStyleConfig::slotUseSgbvClicked(bool en)
{
    useFlb->setEnabled(!useSgbv->isOn());
    emit changed(true);
}

void ThinKeramikStyleConfig::searchScheme()
{
    schemeListBox->clear();
    QStringList schemeDirs (QDir::homeDirPath() + "/.qt");
    schemeDirs << (QString) (QString(getenv("KDEDIR")) + "/share/apps/kdisplay/styleconfs");
    for ( QStringList::Iterator it = schemeDirs.begin(); it != schemeDirs.end(); ++it ) {
        QDir schemeDir(*it, "thinkeramik_*.kcmrc");
	uint schemeCount = schemeDir.count();
	for (uint sidx = 0; sidx<schemeCount; sidx++) {
            QString schemeFile = schemeDir[sidx];
	    uint fnameLen = schemeFile.length();
	    if (fnameLen > 19) {
	        schemeFile = schemeFile.right(fnameLen - 12);
		schemeFile = schemeFile.left(fnameLen - 12 - 6);
		if (!(schemeListBox->findItem(schemeFile))) {
		    if ( (*it).startsWith(QString(getenv("KDEDIR"))+ "/share/apps/kdisplay/styleconfs") ) {
		        schemeFile = "(GLOBAL)" + schemeFile;
		    }
		    schemeListBox->insertItem(schemeFile);
		}
	    }
	}
    }
}

#include "thinkeramikconf.moc"
